#include <iostream>

#include "aopp.hpp"

using namespace AOPP;

int main( int argc, char **argv ) {

    AOSystem aosys;

    int driver_count;
    AOInfo ** driver_list = aosys.driver_info_list( &driver_count );

    std::cout << "Endianness: " << ( aosys.is_big_endian() ? "big" : "little" ) << std::endl;

    int default_driver_id = aosys.default_driver_id();
    if ( -1 == default_driver_id ) {
        std::cout << "No default driver available." << std::endl;
        }

    for (int i=0; i < driver_count; ++i ) {
        std::cout << driver_list[i]->short_name << std::endl;

        int driver_id = AODriver::get_driver_id( driver_list[i]->short_name );

        if ( default_driver_id == driver_id ) {
            std::cout << "\tDEFAULT DRIVER" << std::endl;
            }

        std::cout << "\tID                   \t" << driver_id << std::endl;
        std::cout << "\tName                 \t" << driver_list[i]->name << std::endl;
        std::cout << "\tType                 \t" <<
            ( driver_list[i]->type == AO_TYPE_LIVE ? "live" :
              driver_list[i]->type == AO_TYPE_FILE ? "file" :
              "unknown" )
            << std::endl;
        std::cout << "\tPriority             \t" << driver_list[i]->priority << std::endl;
        std::cout << "\tPreferred byte format\t" << 
            ( driver_list[i]->preferred_byte_format == AO_FMT_LITTLE ? "little" :
              driver_list[i]->preferred_byte_format == AO_FMT_BIG ? "big" :
              "unknown" )
            << std::endl;
        std::cout << "\tcomment              \t" << driver_list[i]->comment << std::endl;
        std::cout << "\toptions" << std::endl;
        for ( int j = 0; j < driver_list[i]->option_count; ++j ) {
            std::cout << "\t\t" << driver_list[i]->options[j] << std::endl;
            }
        }
    }
